@@ -19,6 +19,12 @@ ARGUMENT_MAPPINGS = \
     'j': 'jobs'
 }
 
+# These are flags, so don't associate values with them...
+JUST_FLAGS = \
+{
+    'help', 'keep-going', 'print-expanded', 'just-print', 'silent', 'built-in-shell'
+}
+
 # Don't save these when we recurse...
 NO_SAVE_ARGS = \
 {
@@ -45,7 +51,7 @@ def printHelp():
     print("\t\t Keep going if errors are encountered.")
     cprint("    -n, --just-print", FORMAT_COLORS['GREEN'])
     print("\t Just print commands to be run, without evaluating (print commands, don't send them to the shell). ")
-    cprint("Be aware that $(shell ...) macros are still evaluated. This option only applies to individual commands.")
+    print("Be aware that $(shell ...) macros are still evaluated. This option only applies to individual commands.")
     cprint("    -p", FORMAT_COLORS['GREEN'])
     print("\t\t Rather than finding targets, print the makefile, with top-level targets expanded.")
     cprint("    -C dir", FORMAT_COLORS['GREEN'])
@@ -92,7 +98,7 @@ def printHelp():
 
 # On commandline run...
 def main(args=sys.argv):
-    args = parseArgs(args, ARGUMENT_MAPPINGS)
+    args = parseArgs(args, ARGUMENT_MAPPINGS, strictlyFlags=JUST_FLAGS)
     
     # Fill args from MAKEFLAGS (see https://www.gnu.org/software/make/manual/make.html#How-the-MAKE-Variable-Works)
     args = fillArgsFromEnv(args, "MAKEFLAGS", ARGUMENT_MAPPINGS) # Previously-defined args take precedence.
